.. module:: hubugs.models

``models``
==========

.. note::

   The documentation in this section is aimed at people wishing to contribute
   to :mod:`hubugs`, and can be skipped if you are simply using the tool from
   the command line.

.. autofunction:: object_hook
.. autofunction:: _v2_conv_timestamp
.. autofunction:: from_search
